Intel-XE Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Michal Wajdeczko <michal.wajdeczko@intel.com>
To: intel-xe@lists.freedesktop.org
Cc: Michal Wajdeczko <michal.wajdeczko@intel.com>
Subject: [PATCH 4/5] drm/xe: Rename internal vram helper function
Date: Mon, 27 May 2024 19:35:53 +0200	[thread overview]
Message-ID: <20240527173554.1108-5-michal.wajdeczko@intel.com> (raw)
In-Reply-To: <20240527173554.1108-1-michal.wajdeczko@intel.com>

Drop no longer applicable "xe_mmio_" prefix and downgrade the
existing kernel-doc for internal function to normal comment.

Signed-off-by: Michal Wajdeczko <michal.wajdeczko@intel.com>
---
 drivers/gpu/drm/xe/xe_vram.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_vram.c b/drivers/gpu/drm/xe/xe_vram.c
index d8b81e4e050c..411e8d23fd4d 100644
--- a/drivers/gpu/drm/xe/xe_vram.c
+++ b/drivers/gpu/drm/xe/xe_vram.c
@@ -192,8 +192,8 @@ static inline u64 get_flat_ccs_offset(struct xe_gt *gt, u64 tile_size)
 	return offset;
 }
 
 /**
  * xe_mmio_tile_vram_size() - Collect vram size and offset information
  * @tile: tile to get info for
  * @vram_size: available vram (size - device reserved portions)
  * @tile_size: actual vram size
@@ -211,8 +211,8 @@ static inline u64 get_flat_ccs_offset(struct xe_gt *gt, u64 tile_size)
  * NOTE: multi-tile bases will include the tile offset.
  *
  */
-static int xe_mmio_tile_vram_size(struct xe_tile *tile, u64 *vram_size,
-				  u64 *tile_size, u64 *tile_offset)
+static int tile_vram_size(struct xe_tile *tile, u64 *vram_size,
+			  u64 *tile_size, u64 *tile_offset)
 {
 	struct xe_device *xe = tile_to_xe(tile);
 	struct xe_gt *gt = tile->primary_gt;
@@ -287,7 +287,7 @@ int xe_vram_probe(struct xe_device *xe)
 
 	/* Get the size of the root tile's vram for later accessibility comparison */
 	tile = xe_device_get_root_tile(xe);
-	err = xe_mmio_tile_vram_size(tile, &vram_size, &tile_size, &tile_offset);
+	err = tile_vram_size(tile, &vram_size, &tile_size, &tile_offset);
 	if (err)
 		return err;
 
@@ -302,7 +302,7 @@ int xe_vram_probe(struct xe_device *xe)
 
 	/* tile specific ranges */
 	for_each_tile(tile, xe, id) {
-		err = xe_mmio_tile_vram_size(tile, &vram_size, &tile_size, &tile_offset);
+		err = tile_vram_size(tile, &vram_size, &tile_size, &tile_offset);
 		if (err)
 			return err;
 
@@ -192,8 +192,8 @@ static inline u64 get_flat_ccs_offset(struct xe_gt *gt, u64 tile_size)
 }
 
-/**
- * xe_mmio_tile_vram_size() - Collect vram size and offset information
+/*
+ * tile_vram_size() - Collect vram size and offset information
  * @tile: tile to get info for
  * @vram_size: available vram (size - device reserved portions)
-- 
2.43.0


  parent reply	other threads:[~2024-05-27 17:36 UTC|newest]

Thread overview: 27+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-05-27 17:35 [PATCH 0/5] VF: Setup VRAM based on received config data Michal Wajdeczko
2024-05-27 17:35 ` [PATCH 1/5] drm/xe: Move XEHP_MTCFG_ADDR register definition to xe_regs.h Michal Wajdeczko
2024-05-28 21:14   ` Matt Roper
2024-05-27 17:35 ` [PATCH 2/5] drm/xe: Move BAR definitions to dedicated file Michal Wajdeczko
2024-05-28 21:18   ` Matt Roper
2024-05-27 17:35 ` [PATCH 3/5] drm/xe: Promote VRAM initialization function to own file Michal Wajdeczko
2024-05-28 21:27   ` Matt Roper
2024-05-27 17:35 ` Michal Wajdeczko [this message]
2024-05-28 21:35   ` [PATCH 4/5] drm/xe: Rename internal vram helper function Matt Roper
2024-05-28 22:15     ` Matthew Brost
2024-05-29 11:25       ` Michal Wajdeczko
2024-05-29 11:50         ` Jani Nikula
2024-05-29 12:45           ` Michal Wajdeczko
2024-05-29 12:52             ` Jani Nikula
2024-05-29 16:22               ` Lucas De Marchi
2024-05-29 18:01                 ` Jani Nikula
2024-05-29 20:03                   ` Lucas De Marchi
2024-05-27 17:35 ` [PATCH 5/5] drm/xe/vf: Setup VRAM based on received config data Michal Wajdeczko
2024-05-28 21:50   ` Matt Roper
2024-05-27 17:42 ` ✓ CI.Patch_applied: success for VF: " Patchwork
2024-05-27 17:42 ` ✗ CI.checkpatch: warning " Patchwork
2024-05-27 17:43 ` ✓ CI.KUnit: success " Patchwork
2024-05-27 17:55 ` ✓ CI.Build: " Patchwork
2024-05-27 17:55 ` ✗ CI.Hooks: failure " Patchwork
2024-05-27 17:57 ` ✓ CI.checksparse: success " Patchwork
2024-05-27 18:28 ` ✗ CI.BAT: failure " Patchwork
2024-05-27 19:38 ` ✗ CI.FULL: " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240527173554.1108-5-michal.wajdeczko@intel.com \
    --to=michal.wajdeczko@intel.com \
    --cc=intel-xe@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox